package com.sh.sdk.shareinstall_flutter;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Log;

import com.sh.sdk.shareinstall.ShareInstall;
import com.sh.sdk.shareinstall.listener.AppGetInfoListener;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * ShareinstallFlutterPlugin
 */
public class ShareinstallFlutterPlugin implements MethodCallHandler, PluginRegistry.NewIntentListener {

    private static final String TAG = "shareInstall";

    private static final String GET_WAKEUP = "getWakeUp";
    private static final String GET_INSTALL = "getInstall";
    private static final String REPORT_REGISTER = "reportRegister";
    private static final String CLEAR_APP_GET_INFO_LISTENER = "clearAppGetInfoListener";

    static MethodChannel methodChannel;

    private Activity activity;

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        methodChannel = new MethodChannel(registrar.messenger(), "shareinstall_flutter");
        ShareinstallFlutterPlugin plugin = new ShareinstallFlutterPlugin(registrar.activity());
        methodChannel.setMethodCallHandler(plugin);
        registrar.addNewIntentListener(plugin);
    }

    private ShareinstallFlutterPlugin(Activity activity) {
        //初始化shareinstall
        this.activity = activity;
        ShareInstall.getInstance().init(activity.getApplication());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        String method = call.method;
        if (method.equals(GET_WAKEUP)) {
            getWakeUp(call, result);
            return;
        }
        if (method.equals(GET_INSTALL)) {
            getInstall(call, result);
            return;
        }
        if (method.equals(REPORT_REGISTER)) {
            reportRegister(call, result);
            return;
        }
        if (method.equals(CLEAR_APP_GET_INFO_LISTENER)) {
            clearAppGetInfoListener(call, result);
            return;
        }
        result.notImplemented();
    }

    public void getWakeUp(MethodCall call, final Result result) {
        //Log.e(TAG, "getWakeUp");
        String data = (String) call.arguments;
        Intent intent = new Intent();
        if (!TextUtils.isEmpty(data)) {
            intent.setData(Uri.parse(data));
        }
        ShareInstall.getInstance().getInfo(intent, new AppGetInfoListener() {
            @Override
            public void onGetInfoFinish(String json) {
                result.success(json);
            }
        });
    }

    private static void getWakeUp(Intent intent) {
        //Log.e(TAG, "getWakeUp onNewIntent");
        ShareInstall.getInstance().getInfo(intent, new AppGetInfoListener() {
            @Override
            public void onGetInfoFinish(String json) {
                methodChannel.invokeMethod("wakeup", json);
            }
        });
    }


    public void getInstall(MethodCall call, final Result result) {
        //Log.e(TAG, "getInstall");
        ShareInstall.getInstance().getInfo(activity.getIntent(), new AppGetInfoListener() {
            @Override
            public void onGetInfoFinish(String json) {
                result.success(json);
            }
        });
    }

    public void reportRegister(MethodCall call, Result result) {
        //Log.e(TAG, "reportRegister");
        ShareInstall.getInstance().reportRegister();
        result.success("reportRegister");
    }

    public void clearAppGetInfoListener(MethodCall call, Result result) {
        //Log.e(TAG, "clearAppGetInfoListener");
        ShareInstall.getInstance().clearAppGetInfoListener();
        result.success("clearAppGetInfoListener");
    }

    @Override
    public boolean onNewIntent(Intent intent) {
        //Log.e(TAG, "onNewIntent");
        getWakeUp(intent);
        return false;
    }
}
